scopus: Python-based API-Wrapper to access Scopus
=================================================

scopus is an easy to use Python library to pull, cache and extract data from the Scopus database.

.. include:: installation.rst


=======
Classes
=======

scopus provides classes to interact with the various Scopus APIs (see https://dev.elsevier.com/api_docs.html):

.. currentmodule:: scopus

.. autosummary::

   ScopusAbstract
   ScopusAuthor
   CitationOverview
   AuthorSearch
   ScopusSearch
   ScopusAffiliation


There is one class to provide reports:

.. autosummary::

   report


==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. Hidden links for Navigation side panel
.. toctree::
   :maxdepth: 2
   :hidden:

   examples
   tips
   reference
   configuration
   changelog
   contributing
   authors
